# ezmsg-neo

Load and stream data from [neo](https://github.com/NeuralEnsemble/python-neo) files into [ezmsg](https://github.com/iscoe/ezmsg).

## Installation

TODO: `pip install ezmsg-neo`

For now `pip install ezmsg-neo@git+https://github.com/ezmsg-org/ezmsg-neo`

## Dependencies
* `ezmsg`
* `neo`

## Setup (Development)

1. Clone this repo
2. `uv init`
3. ezmsg-neo modules are available under `import ezmsg.neo`

TODO: See the `examples` folder for more details.
